{% load sample_tags %}

<!DOCTYPE html>
<html>
    <head>
        <title>Django My Lib</title>
    </head>
    <body>
        <h1>Welcome to Django My Lib - Version {{ versao }}</h1>

        <p>To learn more about the library, <a href="{{ url_pypi }}">visit the PyPI page</a></p>
        <p>Check out the source code on <a href="{{ url_github }}">GitHub</a></p>
        <p>This template was loaded directly from the library package!</p>

        <hr>

        <p>{% greeting "My dear visitor" %}</p>
    </body>
</html>
